antares.apps.client.migrations package — Antares 0.0.2 documentation

# antares.apps.client.migrations package

## Submodules

## antares.apps.client.migrations.0001_initial module

## antares.apps.client.migrations.0002_auto_20180624_1759 module

## antares.apps.client.migrations.0003_auto_20190629_1936 module

class `antares.apps.client.migrations.0003_auto_20190629_1936.` `Migration`(name, app_label)

  Bases: `django.db.migrations.migration.Migration`

  `dependencies` = [('client', '0002_auto_20180624_1759')]
  `operations` = [<AlterField model_name='isicposition', name='level', field=<django.db.models.fields.PositiveIntegerField>>, <AlterField model_name='isicposition', name='lft', field=<django.db.models.fields.PositiveIntegerField>>, <AlterField model_name='isicposition', name='rght', field=<django.db.models.fields.PositiveIntegerField>>]

## Module contents